@@ -144,8 +144,9 @@ class AsyncClient(object):
         :param process_func: function to call in process
         """
 
-        if process_func and not isinstance(process_func, FunctionType):
+        if process_func and isinstance(process_func, FunctionType):
             self._process_func = process_func
+        elif process_func:
             raise InterfaceError("process_func must be function")
 
         if not self._openers_pool:
@@ -316,13 +317,13 @@ class AsyncClient(object):
         return self.method("get", url=url, **kwargs)
 
     def post(self, url, data='', **kwargs):
-        return self.method("post", **kwargs)
+        return self.method("post", url=url, data=data, **kwargs)
 
     def head(self, url, **kwargs):
         return self.method("head", url=url, **kwargs)
 
     def options(self, url, **kwargs):
-        return self.method("options", url, **kwargs)
+        return self.method("options", url=url, **kwargs)
 
     def put(self, url, **kwargs):
         return self.method("put", url=url, **kwargs)
