@@ -42,7 +42,9 @@ try:
     import platform
     if platform.system().lower() != 'windows':
         import signal
-        signal.signal(signal.SIGPIPE, signal.SIG_IGN)
+        from threading import current_thread
+        if current_thread().name == 'MainThread':
+            signal.signal(signal.SIGPIPE, signal.SIG_IGN)
 except ImportError:
     pass
 
@@ -746,7 +748,7 @@ class Response(object):
                 if not header:
                     continue
                 elif not header.startswith("HTTP"):
-                    field, value = header.split(":", 1)
+                    field, value = map(lambda u: u.strip(), header.split(":", 1))
                     if field.startswith("Location"):
                         # maybe not good
                         if not value.startswith("http"):
